@@ -87,7 +87,7 @@ def make_app(app, config, template=default_error_template,
         the key determines the name given in the OOPS context. If None is passed
         the default_map_environ is used. Pass {} in to entirely disable mapping.
     :param tracker: A factory function to create a tracker. Trackers are used
-        to allow variations on the WSGI environment to still use oops_wsgi. 
+        to allow variations on the WSGI environment to still use oops_wsgi.
         See generator_tracker for the reference tracker used in regular WSGI
         environments. generator_tracker is used by default or when
         tracker=None.
@@ -193,7 +193,7 @@ def make_app(app, config, template=default_error_template,
                 headers = [('Content-Type', content_type)]
                 headers.append(('X-Oops-Id', str(report['id'])))
                 start_response(
-                    '500 Internal Server Error', headers, exc_info=exc_info)
+                    '500 Internal Server Error', headers, exc_info)
                 del exc_info
                 if error_render is not None:
                     return error_render(report)
@@ -250,3 +250,6 @@ def generator_tracker(on_first_bytes, on_finish, on_error, app_body):
     except Exception:
         exc_info = sys.exc_info()
         yield on_error(exc_info)
+    finally:
+        if hasattr(app_body, 'close'):
+            app_body.close()
